/*
Copyright (C) 2006 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "../headers.h"

LocaleManager::LocaleManager()
{
	// tells the game to default to the
	// pak file for the data
	localePath = "PAKFILE";

	setLanguage(getenv("LANG"));
	
	localeData.clear();
	systemLocaleData.clear();
}

LocaleManager::~LocaleManager()
{
	destroy();
}

void LocaleManager::clear()
{
	localeData.clear();
}

void LocaleManager::destroy()
{
	localeData.clear();
	systemLocaleData.clear();
}

LocaleManager *LocaleManager::getInstance()
{
	return &instance;
}

void LocaleManager::setLocalePath(char *localePath)
{
	this->localePath = localePath;
}

void LocaleManager::setLocaleData(Properties *localeData)
{
	this->localeData.clear();
	this->localeData += localeData;
}

void LocaleManager::appendLocaleData(Properties *localeData)
{
	debug(("LocaleManager::appendLocaleData()\n"));

	this->localeData += localeData;
}

void LocaleManager::setSystemLocaleData(Properties *systemLocaleData)
{
	this->systemLocaleData.clear();
	this->systemLocaleData += systemLocaleData;
}

char *LocaleManager::translateSystemMessage(char *key)
{
	localeKey.setText("%s_%s", key, language);
	
	char *rtn = systemLocaleData.getString(localeKey.getText(), "???");
	
	return (strcmp(rtn, "???")) ? rtn : systemLocaleData.getString(key, "???");
}

char *LocaleManager::translate(char *key)
{
	char *rtn = translateSystemMessage(key);
	
	if (strcmp(rtn, "???"))
	{
		return rtn;
	}
	
	localeKey.setText("%s_%s", key, language);
	
	rtn = localeData.getString(localeKey.getText(), "???");
	
	return (strcmp(rtn, "???")) ? rtn : localeData.getString(key, "???");
}

void LocaleManager::removeLocaleData(char *key)
{
	localeData.removeProperties(key);
	systemLocaleData.removeProperties(key);
}

void LocaleManager::setLanguage(char *language)
{
	if (language == NULL)
	{
		printf("WARNING - LocaleManager::setLanguage - Attempted to set NULL language\n");
		return;
	}
	
	if (strlen(language) < 2)
	{
		printf("WARNING - LocaleManager::setLanguage - '%s' is not a valid language!\n", language);
		return;
	}
	
	strncpy(this->language, language, 2);
	this->language[2] = '\0';
	
	debug(("LocaleManager::setLanguage - %s\n", this->language));
}

char *LocaleManager::getLanguage()
{
	return language;
}

void LocaleManager::listLocaleData()
{
	printf("LocaleManager::listLocaleData()\n");
	localeData.listProperties();
}

LocaleManager LocaleManager::instance;
